contenttypes.ContentType (content type) — amici1

# `contenttypes.ContentType` (content type)

ContentType(id, app_label, model)

Master tables : gfks.ContentTypes (content types)

Database fields:

- ID (id) : See `<django.db.models.fields.AutoField: id>`.

- app label (app_label) : See `<django.db.models.fields.CharField: app_label>`.

- python model class name (model) : See `<django.db.models.fields.CharField: model>`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

Referenced from blogs.Entry.owner_type, cal.Event.owner_type, cal.Task.owner_type, checkdata.Problem.owner_type, comments.Comment.owner_type, comments.Mention.owner_type, excerpts.Excerpt.owner_type, excerpts.ExcerptType.content_type, gfks.HelpText.content_type, topics.Interest.owner_type, uploads.Upload.owner_type

## Database fields

Internal name | Verbose name | Help text
id | ID |
app_label | app label |
model | python model class name |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.